@@ -4,7 +4,7 @@ library(leaflet)
 library(leaflet.minicharts)
 library(htmltools)
 library(sp)
-library(spatstat)
+library(spatstat.core)
 library(maptools)
 library(geosphere)
 library(prodlim)
